@@ -92,7 +92,7 @@ __all__ = (
 
 class DescribeCacheClustersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeCacheClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheClusters)
+    [Paginator.DescribeCacheClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheClusters)
     """
 
     def paginate(
@@ -103,13 +103,13 @@ class DescribeCacheClustersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[CacheClusterMessageTypeDef]:
         """
-        [DescribeCacheClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheClusters.paginate)
+        [DescribeCacheClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheClusters.paginate)
         """
 
 
 class DescribeCacheEngineVersionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeCacheEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheEngineVersions)
+    [Paginator.DescribeCacheEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheEngineVersions)
     """
 
     def paginate(
@@ -121,26 +121,26 @@ class DescribeCacheEngineVersionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[CacheEngineVersionMessageTypeDef]:
         """
-        [DescribeCacheEngineVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheEngineVersions.paginate)
+        [DescribeCacheEngineVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheEngineVersions.paginate)
         """
 
 
 class DescribeCacheParameterGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeCacheParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameterGroups)
+    [Paginator.DescribeCacheParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameterGroups)
     """
 
     def paginate(
         self, CacheParameterGroupName: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[CacheParameterGroupsMessageTypeDef]:
         """
-        [DescribeCacheParameterGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameterGroups.paginate)
+        [DescribeCacheParameterGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameterGroups.paginate)
         """
 
 
 class DescribeCacheParametersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeCacheParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameters)
+    [Paginator.DescribeCacheParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameters)
     """
 
     def paginate(
@@ -150,52 +150,52 @@ class DescribeCacheParametersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[CacheParameterGroupDetailsTypeDef]:
         """
-        [DescribeCacheParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameters.paginate)
+        [DescribeCacheParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameters.paginate)
         """
 
 
 class DescribeCacheSecurityGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeCacheSecurityGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSecurityGroups)
+    [Paginator.DescribeCacheSecurityGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSecurityGroups)
     """
 
     def paginate(
         self, CacheSecurityGroupName: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[CacheSecurityGroupMessageTypeDef]:
         """
-        [DescribeCacheSecurityGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSecurityGroups.paginate)
+        [DescribeCacheSecurityGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSecurityGroups.paginate)
         """
 
 
 class DescribeCacheSubnetGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeCacheSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSubnetGroups)
+    [Paginator.DescribeCacheSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSubnetGroups)
     """
 
     def paginate(
         self, CacheSubnetGroupName: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[CacheSubnetGroupMessageTypeDef]:
         """
-        [DescribeCacheSubnetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSubnetGroups.paginate)
+        [DescribeCacheSubnetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSubnetGroups.paginate)
         """
 
 
 class DescribeEngineDefaultParametersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEngineDefaultParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEngineDefaultParameters)
+    [Paginator.DescribeEngineDefaultParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEngineDefaultParameters)
     """
 
     def paginate(
         self, CacheParameterGroupFamily: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[DescribeEngineDefaultParametersResultTypeDef]:
         """
-        [DescribeEngineDefaultParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEngineDefaultParameters.paginate)
+        [DescribeEngineDefaultParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEngineDefaultParameters.paginate)
         """
 
 
 class DescribeEventsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEvents)
+    [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEvents)
     """
 
     def paginate(
@@ -214,13 +214,13 @@ class DescribeEventsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[EventsMessageTypeDef]:
         """
-        [DescribeEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEvents.paginate)
+        [DescribeEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEvents.paginate)
         """
 
 
 class DescribeGlobalReplicationGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeGlobalReplicationGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeGlobalReplicationGroups)
+    [Paginator.DescribeGlobalReplicationGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeGlobalReplicationGroups)
     """
 
     def paginate(
@@ -230,26 +230,26 @@ class DescribeGlobalReplicationGroupsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeGlobalReplicationGroupsResultTypeDef]:
         """
-        [DescribeGlobalReplicationGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeGlobalReplicationGroups.paginate)
+        [DescribeGlobalReplicationGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeGlobalReplicationGroups.paginate)
         """
 
 
 class DescribeReplicationGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeReplicationGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReplicationGroups)
+    [Paginator.DescribeReplicationGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReplicationGroups)
     """
 
     def paginate(
         self, ReplicationGroupId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ReplicationGroupMessageTypeDef]:
         """
-        [DescribeReplicationGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReplicationGroups.paginate)
+        [DescribeReplicationGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReplicationGroups.paginate)
         """
 
 
 class DescribeReservedCacheNodesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeReservedCacheNodes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodes)
+    [Paginator.DescribeReservedCacheNodes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodes)
     """
 
     def paginate(
@@ -263,13 +263,13 @@ class DescribeReservedCacheNodesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ReservedCacheNodeMessageTypeDef]:
         """
-        [DescribeReservedCacheNodes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodes.paginate)
+        [DescribeReservedCacheNodes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodes.paginate)
         """
 
 
 class DescribeReservedCacheNodesOfferingsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeReservedCacheNodesOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodesOfferings)
+    [Paginator.DescribeReservedCacheNodesOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodesOfferings)
     """
 
     def paginate(
@@ -282,13 +282,13 @@ class DescribeReservedCacheNodesOfferingsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ReservedCacheNodesOfferingMessageTypeDef]:
         """
-        [DescribeReservedCacheNodesOfferings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodesOfferings.paginate)
+        [DescribeReservedCacheNodesOfferings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodesOfferings.paginate)
         """
 
 
 class DescribeServiceUpdatesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeServiceUpdates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeServiceUpdates)
+    [Paginator.DescribeServiceUpdates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeServiceUpdates)
     """
 
     def paginate(
@@ -298,13 +298,13 @@ class DescribeServiceUpdatesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ServiceUpdatesMessageTypeDef]:
         """
-        [DescribeServiceUpdates.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeServiceUpdates.paginate)
+        [DescribeServiceUpdates.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeServiceUpdates.paginate)
         """
 
 
 class DescribeSnapshotsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeSnapshots)
+    [Paginator.DescribeSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeSnapshots)
     """
 
     def paginate(
@@ -317,13 +317,13 @@ class DescribeSnapshotsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeSnapshotsListMessageTypeDef]:
         """
-        [DescribeSnapshots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeSnapshots.paginate)
+        [DescribeSnapshots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeSnapshots.paginate)
         """
 
 
 class DescribeUpdateActionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeUpdateActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUpdateActions)
+    [Paginator.DescribeUpdateActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUpdateActions)
     """
 
     def paginate(
@@ -336,12 +336,20 @@ class DescribeUpdateActionsPaginator(Boto3Paginator):
         ServiceUpdateTimeRange: TimeRangeFilterTypeDef = None,
         UpdateActionStatus: List[
             Literal[
-                "not-applied", "waiting-to-start", "in-progress", "stopping", "stopped", "complete"
+                "not-applied",
+                "waiting-to-start",
+                "in-progress",
+                "stopping",
+                "stopped",
+                "complete",
+                "scheduling",
+                "scheduled",
+                "not-applicable",
             ]
         ] = None,
         ShowNodeLevelUpdateStatus: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[UpdateActionsMessageTypeDef]:
         """
-        [DescribeUpdateActions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUpdateActions.paginate)
+        [DescribeUpdateActions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUpdateActions.paginate)
         """
