@@ -145,6 +145,7 @@ CacheSecurityGroupTypeDef = TypedDict(
         "CacheSecurityGroupName": str,
         "Description": str,
         "EC2SecurityGroups": List[EC2SecurityGroupTypeDef],
+        "ARN": str,
     },
     total=False,
 )
@@ -236,6 +237,7 @@ CacheClusterTypeDef = TypedDict(
         "AuthTokenLastModifiedDate": datetime,
         "TransitEncryptionEnabled": bool,
         "AtRestEncryptionEnabled": bool,
+        "ARN": str,
     },
     total=False,
 )
@@ -321,6 +323,7 @@ CacheParameterGroupTypeDef = TypedDict(
         "CacheParameterGroupFamily": str,
         "Description": str,
         "IsGlobal": bool,
+        "ARN": str,
     },
     total=False,
 )
@@ -352,6 +355,7 @@ CacheSubnetGroupTypeDef = TypedDict(
         "CacheSubnetGroupDescription": str,
         "VpcId": str,
         "Subnets": List[SubnetTypeDef],
+        "ARN": str,
     },
     total=False,
 )
@@ -422,6 +426,7 @@ ReplicationGroupTypeDef = TypedDict(
         "NodeGroups": List[NodeGroupTypeDef],
         "SnapshottingClusterId": str,
         "AutomaticFailover": Literal["enabled", "disabled", "enabling", "disabling"],
+        "MultiAZ": Literal["enabled", "disabled"],
         "ConfigurationEndpoint": EndpointTypeDef,
         "SnapshotRetentionLimit": int,
         "SnapshotWindow": str,
@@ -432,6 +437,7 @@ ReplicationGroupTypeDef = TypedDict(
         "TransitEncryptionEnabled": bool,
         "AtRestEncryptionEnabled": bool,
         "KmsKeyId": str,
+        "ARN": str,
     },
     total=False,
 )
@@ -506,6 +512,7 @@ SnapshotTypeDef = TypedDict(
         "AutomaticFailover": Literal["enabled", "disabled", "enabling", "disabling"],
         "NodeSnapshots": List[NodeSnapshotTypeDef],
         "KmsKeyId": str,
+        "ARN": str,
     },
     total=False,
 )
@@ -567,6 +574,7 @@ GlobalReplicationGroupTypeDef = TypedDict(
         "AuthTokenEnabled": bool,
         "TransitEncryptionEnabled": bool,
         "AtRestEncryptionEnabled": bool,
+        "ARN": str,
     },
     total=False,
 )
@@ -875,7 +883,15 @@ ProcessedUpdateActionTypeDef = TypedDict(
         "CacheClusterId": str,
         "ServiceUpdateName": str,
         "UpdateActionStatus": Literal[
-            "not-applied", "waiting-to-start", "in-progress", "stopping", "stopped", "complete"
+            "not-applied",
+            "waiting-to-start",
+            "in-progress",
+            "stopping",
+            "stopped",
+            "complete",
+            "scheduling",
+            "scheduled",
+            "not-applicable",
         ],
     },
     total=False,
@@ -956,7 +972,15 @@ UpdateActionTypeDef = TypedDict(
         "ServiceUpdateType": Literal["security-update"],
         "UpdateActionAvailableDate": datetime,
         "UpdateActionStatus": Literal[
-            "not-applied", "waiting-to-start", "in-progress", "stopping", "stopped", "complete"
+            "not-applied",
+            "waiting-to-start",
+            "in-progress",
+            "stopping",
+            "stopped",
+            "complete",
+            "scheduling",
+            "scheduled",
+            "not-applicable",
         ],
         "NodesUpdated": str,
         "UpdateActionStatusModifiedDate": datetime,
